@@ -170,7 +170,7 @@ end subroutine PGBBUF
 
 !------------------------------------------------------------------------
 ! Module: PGBEG -- open a graphics device
-! Status: PARTIALLY IMPLEMENTED
+! Status: IMPLEMENTED
 !------------------------------------------------------------------------
 integer function PGBEG (UNIT, FILE, NXSUB, NYSUB)
  implicit none
@@ -180,21 +180,31 @@ integer function PGBEG (UNIT, FILE, NXSUB, NYSUB)
  integer, external :: PGOPEN
 
  PGBEG = PGOPEN(FILE)
- if (NXSUB.GT.1 .or. NYSUB.GT.1) then
-    print "(a)",' WARNING: multiple panels in PGBEG call not implemented in giza'
+ if (PGBEG > 0 .and. (NXSUB.GT.1 .or. NYSUB.GT.1)) then
+    call PGSUBP(NXSUB, NYSUB)
  endif
 
 end function PGBEG
 
 !------------------------------------------------------------------------
 ! Module: PGBIN -- histogram of binned data
-! Status: NOT IMPLEMENTED
+! Status: IMPLEMENTED
 !------------------------------------------------------------------------
 subroutine PGBIN (NBIN, X, DATA, CENTER)
+ use giza, only:giza_histogram_binned
  implicit none
  integer, intent(in) :: NBIN
  real,    intent(in) :: X(*), DATA(*)
  logical, intent(in) :: CENTER
+ integer :: iflag
+
+ if (CENTER) then
+    iflag = 1
+ else
+    iflag = 0
+ endif 
+
+ call giza_histogram_binned(NBIN, X, DATA, iflag)
 
 end subroutine PGBIN
 
@@ -579,15 +589,18 @@ end subroutine PGHI2D
 
 !------------------------------------------------------------------------
 ! Module: PGHIST -- histogram of unbinned data
-! Status: NOT IMPLEMENTED
+! Status: IMPLEMENTED
 !------------------------------------------------------------------------
 subroutine PGHIST(N, DATA, DATMIN, DATMAX, NBIN, PGFLAG)
+ use giza, only:giza_histogram
  implicit none
  integer, intent(in) :: N
  real,    intent(in) :: DATA(*)
  real,    intent(in) :: DATMIN, DATMAX
  integer, intent(in) :: NBIN, PGFLAG
 
+ call giza_histogram(N,DATA,DATMIN,DATMAX,NBIN,PGFLAG)
+
 end subroutine PGHIST
 
 !------------------------------------------------------------------------
@@ -796,12 +809,15 @@ end subroutine PGPAGE
 
 !------------------------------------------------------------------------
 ! Module: PGPANL -- switch to a different panel on the view surface
-! Status: NOT IMPLEMENTED
+! Status: IMPLEMENTED
 !------------------------------------------------------------------------
 subroutine PGPANL(IX, IY)
+ use giza, only:giza_set_panel
  implicit none
  integer, intent(in) :: IX, IY
 
+ call giza_set_panel(IX, IY)
+
 end subroutine PGPANL
 
 !------------------------------------------------------------------------
@@ -1588,12 +1604,15 @@ end subroutine PGSTBG
 
 !------------------------------------------------------------------------
 ! Module: PGSUBP -- subdivide view surface into panels
-! Status: NOT IMPLEMENTED
+! Status: IMPLEMENTED
 !------------------------------------------------------------------------
 subroutine PGSUBP (NXSUB, NYSUB)
+ use giza, only:giza_subpanel
  implicit none
  integer, intent(in) :: NXSUB, NYSUB
 
+ call giza_subpanel(NXSUB, NYSUB)
+
 end subroutine PGSUBP
 
 !------------------------------------------------------------------------
