@@ -1,7 +1,7 @@
 /* giza - a scientific plotting library built on cairo
  *
  * Copyright (c) 2010      James Wetter and Daniel Price
- * Copyright (c) 2010-2012 Daniel Price
+ * Copyright (c) 2010-2014 Daniel Price
  *
  * This library is free software; and you are welcome to redistribute
  * it under the terms of the GNU General Public License
@@ -44,6 +44,7 @@
 #include "giza-line-style-private.h"
 #include "giza-band-private.h"
 #include "giza-stroke-private.h"
+#include "giza-subpanel-private.h"
 #include "giza-text-background-private.h"
 #include <giza.h>
 #include <stdlib.h>
@@ -210,6 +211,7 @@ giza_open_device_size (const char *newDeviceName, const char *newPrefix, double
     }
 
   /* some final initialisation */
+  _giza_init_subpanel ();
   Dev[id].drawn = 0;
   Dev[id].resize = 0;
   Dev[id].fontAngle = 0.;
@@ -287,7 +289,7 @@ giza_get_device_id (int *devid)
  * Input:
  *  -devid :- device id, as returned by giza_open_device
  *
- * See also: giza_get_device_id
+ * See also: giza_get_device_id, giza_open_device
  */
 void
 giza_select_device (int devid)
@@ -387,10 +389,20 @@ _giza_resize_device (int width, int height)
  * Synopsis: Advances the currently open device to the next page, and redraws
  * the background. If no other actions have been performed since the device was
  * opened or the last call to giza_change_page the call is ignored.
+ *
+ * See also: giza_subpanel, giza_set_panel
  */
 void
 giza_change_page (void)
 {
+
+  /* If sub-panels are used, just change panel if we are not in the last panel */
+  if (Dev[id].nx > 1 || Dev[id].ny > 1) {
+     int newpage;
+     _giza_advance_panel(&newpage);
+     if (!newpage) return;
+  }
+
    /* allow resizing of the device if nothing has been drawn */
   if (!Dev[id].drawn && !Dev[id].resize) {
 
@@ -455,8 +467,9 @@ giza_change_page (void)
   Dev[id].pgNum++;
 
   /* Reset stuff */
-  giza_set_viewport (Dev[id].VP.xmin,Dev[id].VP.xmax, 
-                     Dev[id].VP.ymin, Dev[id].VP.ymax);
+  giza_set_panel(1,1); /* also calls set_viewport */
+  /*giza_set_viewport (Dev[id].VP.xmin,Dev[id].VP.xmax, 
+                     Dev[id].VP.ymin, Dev[id].VP.ymax);*/
   giza_set_window (Dev[id].Win.xmin, Dev[id].Win.xmax,
                    Dev[id].Win.ymin, Dev[id].Win.ymax);
 
@@ -484,6 +497,7 @@ giza_close_device (void)
 
   if (Dev[id].prompting && Dev[id].isInteractive)
     {
+      cairo_surface_finish (Dev[id].surface);
       _giza_newpage_prompt();
     }
 
@@ -756,6 +770,9 @@ _giza_device_to_int (const char *newDeviceName)
     newDevice = GIZA_DEVICE_NULL;
 #ifdef _GIZA_HAS_XW
   else if (!strcmp (devName, "/xw")
+        || !strcmp (devName, "/xs")
+        || !strcmp (devName, "/xserve")
+        || !strcmp (devName, "/xwindow")
         || !strcmp (devName, "/xwin"))
     newDevice = GIZA_DEVICE_XW;
 #endif
