@@ -32,10 +32,15 @@
 module exact
   implicit none
   !
+  !--maximum number of solutions in any one plot
+  !
+  integer, parameter :: maxexact=10
+  !
   !--options used to plot the exact solution line
   !
   integer :: maxexactpts, iExactLineColour, iExactLineStyle,iPlotExactOnlyOnPanel
   logical :: iApplyTransExactFile,iCalculateExactErrors,iPlotResiduals
+  logical :: iApplyUnitsExactFile
   real :: fracinsetResiduals,residualmax
   !
   !--declare all of the parameters required for the various exact solutions
@@ -60,14 +65,14 @@ module exact
   integer :: iprofile,icolpoten,icolfgrav
   real, dimension(2) :: Msphere,rsoft
   !--from file
-  integer :: iexactplotx, iexactploty
+  integer :: iexactplotx(maxexact), iexactploty(maxexact)
   !--shock tube
   real :: rho_L, rho_R, pr_L, pr_R, v_L, v_R
   !--rho vs h
   real :: hfact
   !--read from file
-  integer :: ixcolfile,iycolfile
-  character(len=120) :: filename_exact
+  integer :: ixcolfile(maxexact),iycolfile(maxexact),nfiles
+  character(len=120) :: filename_exact(maxexact)
   !--equilibrium torus
   real :: Mstar,Rtorus,distortion
   !--ring spreading
@@ -76,10 +81,10 @@ module exact
   real :: cs,Kdrag,rhozero,rdust_to_gas
   !--arbitrary function
   integer :: nfunc
-  character(len=120), dimension(10) :: funcstring
+  character(len=120), dimension(maxexact) :: funcstring
   !--Roche potential
   real :: mprim,msec
-  real, dimension(3) :: xprim,xsec
+  real :: xprim(3),xsec(3)
   logical :: use_sink_data
   integer, parameter :: iexact_rochelobe = 15
   !--C-shock
@@ -89,7 +94,8 @@ module exact
   !
   namelist /exactopts/ iexactplotx,iexactploty,filename_exact,maxexactpts, &
        iExactLineColour,iExactLineStyle,iApplyTransExactFile,iCalculateExactErrors, &
-       iPlotResiduals,fracinsetResiduals,residualmax,iPlotExactOnlyOnPanel
+       iPlotResiduals,fracinsetResiduals,residualmax,iPlotExactOnlyOnPanel,&
+       iApplyUnitsExactFile
 
   namelist /exactparams/ ampl,lambda,period,iwaveploty,iwaveplotx,xzero, &
        htstar,atstar,ctstar,alphatstar,betatstar,ctstar1,ctstar2, &
@@ -98,7 +104,7 @@ module exact
        iprofile,Msphere,rsoft,icolpoten,icolfgrav,Mstar,Rtorus,distortion, &
        Mring,Rring,viscnu,nfunc,funcstring,cs,Kdrag,rhozero,rdust_to_gas, &
        mprim,msec,ixcolfile,iycolfile,xshock,totmass,machs,macha,&
-       use_sink_data,xprim,xsec
+       use_sink_data,xprim,xsec,nfiles
 
   public :: defaults_set_exact,submenu_exact,options_exact,read_exactparams
   public :: exact_solution
@@ -109,7 +115,6 @@ contains
   ! sets default values of the exact solution parameters
   !----------------------------------------------------------------------
   subroutine defaults_set_exact
-    implicit none
 
     lambda = 1.0    ! sound wave exact solution : wavelength
     ampl = 0.005    ! sound wave exact solution : amplitude
@@ -138,14 +143,16 @@ contains
     pr_R = 0.1
     v_L = 0.0
     v_R = 0.0
-    iexactplotx = 0
-    iexactploty = 0
     ishk = 1
     xshock = 0.
     hfact = 1.2
+!   read from file
+    nfiles = 1
     filename_exact = ' '
     ixcolfile = 1
     iycolfile = 2
+    iexactplotx = 0
+    iexactploty = 0
 !   density profile parameters
     iprofile = 1
     rsoft(1) = 1.0
@@ -186,6 +193,7 @@ contains
     iExactLineColour = 1    ! foreground
     iExactLineStyle = 1     ! solid
     iApplyTransExactFile = .true. ! false if exact from file is already logged
+    iApplyUnitsExactFile = .false.
     iCalculateExactErrors = .true.
     iPlotResiduals = .false.
     fracinsetResiduals = 0.15
@@ -204,12 +212,12 @@ contains
     use filenames,     only:rootname,ifileopen
     use exactfunction, only:check_function
     use mhdshock,      only:nmhdshocksolns,mhdprob
-    use asciiutils,    only:get_ncolumns,string_replace
-    implicit none
+    use asciiutils,    only:get_ncolumns,get_nrows,string_replace
     integer, intent(inout) :: iexact
-    integer :: ierr,itry,i,ncols,nheaderlines
-    logical :: ians,iexist
+    integer :: ierr,itry,i,ncols,nheaderlines,nadjust,nrows
+    logical :: ians,iexist,ltmp
     character(len=len(filename_exact)) :: filename_tmp
+    character(len=4) :: str
 
     print 10
 10  format(' 0) none ',/,               &
@@ -236,14 +244,14 @@ contains
     !
     select case(iexact)
     case(1)
-       call prompt('enter number of functions to plot ',nfunc,1,size(funcstring))
+       call prompt('enter number of functions to plot ',nfunc,1,maxexact)
        print "(/,a,6(/,11x,a))",' Examples: sin(2*pi*x - 0.1*t)','sqrt(0.5*x)','x^2', &
              'exp(-2*x**2 + 0.1*t)','log10(x/2)','exp(y),y=sin(pi*x)','cos(z/y),z=acos(y),y=x^2'
        overfunc: do i=1,nfunc
           ierr = 1
           itry = 0
           do while(ierr /= 0 .and. itry.lt.10)
-             if (nfunc.gt.1) print "(/,a,i2,/,11('-'),/)",'Function ',i
+             if (nfunc > 1) print "(/,a,i2,/,11('-'),/)",'Function ',i
              call prompt('enter function f(x,t) to plot ',funcstring(i),noblank=.true.)
              call check_function(funcstring(i),ierr)
              if (ierr /= 0 .and. len(funcstring(i)).eq.len_trim(funcstring(i))) then
@@ -253,61 +261,95 @@ contains
              endif
              itry = itry + 1
           enddo
-          if (itry.ge.10) then
+          if (itry >= 10) then
              print "(a)",' *** too many tries, aborting ***'
              ierr = i-1
              exit overfunc
           endif
+          print*
+          call prompt('enter y axis of exact solution (0=all plots)',iexactploty(i),0)
+          if (iexactploty(i) > 0) then
+             call prompt('enter x axis of exact solution ',iexactplotx(i),1)
+          endif
        enddo overfunc
        if (ierr /= 0) nfunc = ierr
-       if (nfunc.gt.0) then
-          print*
-          call prompt('enter y axis of exact solution (0=all plots)',iexactploty,0)
-          if (iexactploty.gt.0) then
-             call prompt('enter x axis of exact solution ',iexactplotx,1)
-          endif
-       endif
     case(2)
-       iexist = .false.
-       do while(.not.iexist)
-          print "(a)",'Use %f to represent current dump file, e.g. %f.exact looks for dump_000.exact'
-          call prompt('enter filename ',filename_exact)
-          !--substitute %f for filename
-          filename_tmp = filename_exact
-          call string_replace(filename_tmp,'%f',trim(rootname(ifileopen)))
-          !--check the first file for errors
-          inquire(file=filename_tmp,exist=iexist)
-          if (iexist) then
-             open(unit=33,file=filename_tmp,status='old',iostat=ierr)
-             if (ierr.eq.0) then
-                call get_ncolumns(33,ncols,nheaderlines)
-                if (ncols.gt.2) then
-                   print "(a,i2,a)",' File '//trim(filename_tmp)//' contains ',ncols,' columns of data'
-                   call prompt('Enter column containing x data ',ixcolfile,1,ncols)
-                   call prompt('Enter column containing y data ',iycolfile,1,ncols)
-                elseif (ncols.eq.2) then
-                   print "(a,i2,a)",' OK: got ',ncols,' columns from '//trim(filename_tmp)
+       call prompt('enter number of files to read per plot ',nfiles,1,maxexact)
+       nadjust = -1
+       over_files: do i=1,nfiles
+          iexist = .false.
+          do while(.not.iexist)
+             print "(/,a)",'Use %f to represent current dump file, e.g. %f.exact looks for dump_000.exact'
+             write(str,"(i4)") i
+             call prompt('enter filename #'//trim(adjustl(str)),filename_exact(i))
+             !--substitute %f for filename
+             filename_tmp = filename_exact(i)
+             call string_replace(filename_tmp,'%f',trim(rootname(ifileopen)))
+             !--check the first file for errors
+             inquire(file=filename_tmp,exist=iexist)
+             if (iexist) then
+                open(unit=33,file=filename_tmp,status='old',iostat=ierr)
+                if (ierr.eq.0) then
+                   call get_ncolumns(33,ncols,nheaderlines)
+                   call get_nrows(33,nheaderlines,nrows)
+                   if (nrows < 100000) then
+                      print "(a,i5,a)",' got ',nrows,' lines in file'
+                   else
+                      print "(a,i10,a)",' got ',nrows,' lines in file'
+                   endif
+                   if (nrows > maxexactpts) maxexactpts = nrows
+                   if (ncols.gt.2) then
+                      print "(a,i2,a)",' File '//trim(filename_tmp)//' contains ',ncols,' columns of data'
+                      call prompt('Enter column containing x data ',ixcolfile(i),1,ncols)
+                      call prompt('Enter column containing y data ',iycolfile(i),1,ncols)
+                   elseif (ncols.eq.2) then
+                      print "(a,i2,a)",' OK: got ',ncols,' columns from '//trim(filename_tmp)
+                   else
+                      iexist = .false.
+                      call prompt('Error: file contains < 2 readable columns: try again?',ians)
+                      if (.not.ians) then
+                         nadjust = i-1
+                         exit over_files
+                      endif
+                   endif
+                   close(33)
                 else
                    iexist = .false.
-                   call prompt('Error: file contains < 2 readable columns: try again?',ians)
-                   if (.not.ians) return
+                   call prompt('Error opening '//trim(filename_tmp)//': try again?',ians)
+                   if (.not.ians) then
+                      nadjust = i-1
+                      exit over_files                      
+                   endif
                 endif
-                close(33)
              else
-                iexist = .false.
-                call prompt('Error opening '//trim(filename_tmp)//': try again?',ians)
-                if (.not.ians) return
+                ians = .true.
+                call prompt('file does not exist: try again? ',ians)
+                if (.not.ians) then
+                   nadjust = i-1
+                   exit over_files
+                endif
              endif
-          else
-             ians = .true.
-             call prompt('file does not exist: try again? ',ians)
-             if (.not.ians) return
+          enddo
+          call prompt('enter x axis of exact solution ',iexactplotx(i),1)
+          call prompt('enter y axis of exact solution ',iexactploty(i),1)
+       enddo over_files
+       if (nadjust >= 0) then
+          nfiles = nadjust
+          if (nfiles == 1) then
+             print "(/,a)",'Using 1 file only'          
+          elseif (nfiles > 0) then
+             write(str,"(i4)") nfiles
+             print "(/,a)",'Using '//trim(adjustl(str))//' files'
           endif
-       enddo
-       call prompt('enter x axis of exact solution ',iexactplotx,1)
-       call prompt('enter y axis of exact solution ',iexactploty,1)
-       print "(a)",'apply column transformations to exact solution?'
-       call prompt(' (no if file contains e.g. log y vs log x)',iApplyTransExactFile)
+       endif
+       if (nfiles > 0) then ! only ask if filename was read OK
+          ltmp = .not.iApplyTransExactFile
+          call prompt(' are exact solutions already logged?',ltmp)
+          iApplyTransExactFile = .not.ltmp
+          ltmp = .not.iApplyUnitsExactFile
+          call prompt(' are exact solutions in physical units?',ltmp)
+          iApplyUnitsExactFile = .not.ltmp
+       endif
     case(3,13)
        !
        !--read shock parameters from the .shk file
@@ -480,10 +522,9 @@ contains
     use exactfunction,  only:check_function
     use filenames,      only:fileprefix
     use asciiutils,     only:read_asciifile,get_line_containing
-    implicit none
-    integer, intent(in) :: iexact
-    character(len=*), intent(in) :: rootname
-    integer, intent(out) :: ierr
+    integer,          intent(in)  :: iexact
+    character(len=*), intent(in)  :: rootname
+    integer,          intent(out) :: ierr
 
     integer :: idash,nf,i,j,idrag,idum,linenum
     character(len=len_trim(rootname)+8) :: filename
@@ -697,20 +738,18 @@ contains
     use gresho,          only:exact_gresho
     use Cshock,          only:exact_Cshock
     use transforms,      only:transform,transform_inverse
-    use plotlib,         only:plot_qci,plot_qls,plot_sci,plot_sls,plot_line
-    implicit none
+    use plotlib,         only:plot_qci,plot_qls,plot_sci,plot_sls,plot_line,plotlib_maxlinestyle
     integer, intent(in) :: iexact,iplotx,iploty,itransx,itransy,igeom
     integer, intent(in) :: ndim,ndimV,npart,imarker,iaxisy
-    real, intent(in) :: time,xmin,xmax,gamma,unitsx,unitsy
-    real, intent(in) :: pmassmin,pmassmax
-    real, intent(in), dimension(npart) :: xplot,yplot
+    real,    intent(in) :: time,xmin,xmax,gamma,unitsx,unitsy
+    real,    intent(in) :: pmassmin,pmassmax
+    real,    intent(in) :: xplot(npart),yplot(npart)
     logical, intent(in) :: irescale
-    real, dimension(npart) :: residuals,ypart
 
     real, parameter :: zero = 1.e-10
-    integer :: i,ierr,iexactpts,iCurrentColour,iCurrentLineStyle
-    real, dimension(:), allocatable :: xexact,yexact,xtemp
-    real :: dx,errL1,errL2,errLinf,timei
+    integer :: i,ierr,iexactpts,iCurrentColour,iCurrentLineStyle,LineStyle
+    real, allocatable :: xexact(:),yexact(:),xtemp(:)
+    real :: dx,timei
     character(len=len(filename_exact)) :: filename_tmp
 
     !
@@ -773,34 +812,41 @@ contains
 
     select case(iexact)
     case(1) ! arbitrary function parsing
-       if ((iplotx.eq.iexactplotx .and. iploty.eq.iexactploty) .or. iexactploty.eq.0) then
-          do i=1,nfunc
+       do i=1,nfunc
+          if ((iplotx.eq.iexactplotx(i) .and. iploty.eq.iexactploty(i)) .or. iexactploty(i).eq.0) then
              call exact_function(funcstring(i),xexact,yexact,timei,ierr)
-             if (i.ne.nfunc) then ! plot all except last line here
-                if (itransy.gt.0) call transform(yexact,itransy)
-                !--use xtemp, which is xexact but already transformed
-                call plot_line(iexactpts,xtemp(1:iexactpts),yexact(1:iexactpts))
-             endif
-          enddo
-       endif
+             !--plot each solution separately and calculate errors
+             call plot_exact_solution(itransx,itransy,iexactpts,npart,&
+                                      xexact,yexact,xplot,yplot,imarker,iaxisy)
+             ierr = 1 ! indicate that we have already plotted the solution
+          endif
+       enddo
     case(2) ! exact solution read from file
-       if (iplotx.eq.iexactplotx .and. iploty.eq.iexactploty) then
-          !--substitute %f for filename
-          filename_tmp = filename_exact
-          call string_replace(filename_tmp,'%f',trim(rootname(ifileopen)))
-          !--read exact solution from file
-          call exact_fromfile(filename_tmp,xexact,yexact,ixcolfile,iycolfile,iexactpts,ierr)
-          !--plot this untransformed (as may already be in log space)
-          if (ierr.le.0 .and. .not.iApplyTransExactFile) then
-             call plot_line(iexactpts,xexact(1:iexactpts),yexact(1:iexactpts))
-             ierr = 1
+       do i=1,nfiles
+          if (iplotx.eq.iexactplotx(i) .and. iploty.eq.iexactploty(i)) then
+             !--substitute %f for filename
+             filename_tmp = filename_exact(i)
+             call string_replace(filename_tmp,'%f',trim(rootname(ifileopen)))
+             !--read exact solution from file
+             call exact_fromfile(filename_tmp,xexact,yexact,ixcolfile(i),iycolfile(i),iexactpts,ierr)
+             !--plot this untransformed (as may already be in log space)
+             if (ierr <= 0) then
+                if (iApplyTransExactFile) then
+                   !--change into physical units if appropriate
+                   if (iRescale .and. iApplyUnitsExactFile) then
+                      xexact(1:iexactpts) = xexact(1:iexactpts)*unitsx
+                      yexact(1:iexactpts) = yexact(1:iexactpts)*unitsy
+                   endif
+                endif
+                !--change line style between files
+                LineStyle = mod(iExactLineStyle+i-1,plotlib_maxlinestyle)
+                !--plot each solution separately and calculate errors
+                call plot_exact_solution(itransx,itransy,iexactpts,npart,&
+                                         xexact,yexact,xplot,yplot,imarker,iaxisy,ls=LineStyle)
+                ierr = 1 ! indicate that we have already plotted the solution
+             endif
           endif
-          !--change into physical units if appropriate
-          if (iRescale .and. iApplyTransExactFile) then
-             xexact(1:iexactpts) = xexact(1:iexactpts)*unitsx
-             yexact(1:iexactpts) = yexact(1:iexactpts)*unitsy
-          endif
-       endif
+       enddo
     case(3)! shock tube
        if (iplotx.eq.ix(1) .and. igeom.le.1) then
           if (iploty.eq.irho) then
@@ -925,7 +971,7 @@ contains
           endif
        endif
 
-    case(7)! linear wave
+    case(7)! Gresho vortex
        !if ((iploty.eq.iwaveploty).and.(iplotx.eq.iwaveplotx)) then
        !   ymean = SUM(yplot(1:npart))/REAL(npart)
        !   call exact_wave(timei,ampl,period,lambda,xzero,ymean,xexact,yexact,ierr)
@@ -1055,10 +1101,26 @@ contains
        endif
     case(14) ! dusty wave exact solution
        if (iplotx.eq.ix(1) .and. igeom.le.1) then
-          if (iploty.eq.irho) then
+          if (iploty.eq.ivx) then
+             !--plot gas solution and calculate errors
              call exact_dustywave(1,timei,ampl,cs,Kdrag,lambda,xzero,rhozero,rhozero*rdust_to_gas,xexact,yexact,ierr)
-          elseif (iploty.eq.ivx) then
-             call exact_dustywave(2,timei,ampl,cs,Kdrag,lambda,xzero,rhozero,rhozero*rdust_to_gas,xexact,yexact,ierr)
+             call plot_exact_solution(itransx,itransy,iexactpts,npart,xexact,yexact,xplot,yplot,imarker,iaxisy,ls=1)
+             !--plot dust solution
+             if (Kdrag > 0.) then
+                call exact_dustywave(2,timei,ampl,cs,Kdrag,lambda,xzero,rhozero,rhozero*rdust_to_gas,xexact,yexact,ierr)
+                call plot_exact_solution(itransx,itransy,iexactpts,npart,xexact,yexact,xplot,yplot,imarker,iaxisy,ls=2,err=.false.)
+             endif
+             ierr = 1
+          elseif (iploty.eq.irho) then
+             !--plot gas solution and calculate errors
+             call exact_dustywave(3,timei,ampl,cs,Kdrag,lambda,xzero,rhozero,rhozero*rdust_to_gas,xexact,yexact,ierr)
+             call plot_exact_solution(itransx,itransy,iexactpts,npart,xexact,yexact,xplot,yplot,imarker,iaxisy,ls=1)
+             !--plot dust solution
+             if (Kdrag > 0.) then
+                call exact_dustywave(4,timei,ampl,cs,Kdrag,lambda,xzero,rhozero,rhozero*rdust_to_gas,xexact,yexact,ierr)
+                call plot_exact_solution(itransx,itransy,iexactpts,npart,xexact,yexact,xplot,yplot,imarker,iaxisy,ls=2,err=.false.)
+             endif
+             ierr = 1
           endif
        endif
     case(15) ! Roche potential
@@ -1084,28 +1146,8 @@ contains
     !----------------------------------------------------------
     !  plot this as a line on the current graph
     !----------------------------------------------------------
-    if (ierr.le.0) then
-       if (itransx.gt.0) call transform(xexact(1:iexactpts),itransx)
-       if (itransy.gt.0) call transform(yexact(1:iexactpts),itransy)
-       call plot_line(iexactpts,xexact(1:iexactpts),yexact(1:iexactpts))
-       !
-       !--calculate errors
-       !
-       if (iCalculateExactErrors) then
-          !--untransform y axis again for error calculation
-          if (itransy.gt.0) call transform_inverse(yexact(1:iexactpts),itransy)
-          !--untransform particle y axis also
-          ypart(1:npart) = yplot(1:npart)
-          if (itransy.gt.0) call transform_inverse(ypart(1:npart),itransy)
-          !--calculate errors
-          call calculate_errors(xexact(1:iexactpts),yexact(1:iexactpts), &
-                                xplot(1:npart),ypart(1:npart),residuals(1:npart), &
-                                errL1,errL2,errLinf)
-          print "(3(a,1pe10.3,1x))",' L1 error = ',errL1,' L2 error = ',errL2, &
-                                   ' L(infinity) error = ',errLinf
-          if (iPlotResiduals) call plot_residuals(xplot,residuals,imarker,iaxisy)
-       endif
-    endif
+    if (ierr <= 0) call plot_exact_solution(itransx,itransy,iexactpts,npart,&
+                                            xexact,yexact,xplot,yplot,imarker,iaxisy)
     !
     !--reset line and colour settings
     !
@@ -1122,13 +1164,62 @@ contains
 
   end subroutine exact_solution
 
+  !------------------------------------------------------------------
+  ! Wrapper routine to plot the exact solution line on current graph
+  ! and calculate errors with respect to the data
+  !------------------------------------------------------------------
+  subroutine plot_exact_solution(itransx,itransy,iexactpts,np,xexact,yexact,xplot,yplot,imarker,iaxisy,ls,err)
+   use transforms, only:transform,transform_inverse
+   use plotlib,    only:plot_line,plot_sls
+   integer, intent(in)    :: itransx,itransy,iexactpts,np,imarker,iaxisy
+   real,    intent(inout) :: xexact(:),yexact(:)
+   real,    intent(in)    :: xplot(:),yplot(:)
+   integer, intent(in), optional :: ls
+   logical, intent(in), optional :: err
+   real :: residuals(np),ypart(np)
+   real :: errL1,errL2,errLinf
+   logical :: plot_err
+
+   if (itransx > 0) call transform(xexact(1:iexactpts),itransx)
+   if (itransy > 0) call transform(yexact(1:iexactpts),itransy)
+   
+   if (present(ls)) call plot_sls(ls)
+   call plot_line(iexactpts,xexact(1:iexactpts),yexact(1:iexactpts))
+   !
+   !--calculate errors
+   !
+   if (present(err)) then
+      plot_err = err
+   else
+      plot_err = .true.   
+   endif
+
+   if (iCalculateExactErrors .and. plot_err) then
+      !--untransform y axis again for error calculation
+      if (itransy > 0) call transform_inverse(yexact(1:iexactpts),itransy)
+      !--untransform particle y axis also
+      ypart(1:np) = yplot(1:np)
+      if (itransy > 0) call transform_inverse(ypart(1:np),itransy)
+      !--calculate errors
+      call calculate_errors(xexact(1:iexactpts),yexact(1:iexactpts), &
+                            xplot(1:np),ypart,residuals, &
+                            errL1,errL2,errLinf)
+      print "(3(a,es10.3,1x))",' L1 error = ',errL1,' L2 error = ',errL2, &
+                               ' L(infinity) error = ',errLinf
+      if (iPlotResiduals) call plot_residuals(xplot,residuals,imarker,iaxisy)
+   endif
+
+  end subroutine plot_exact_solution
+
+  !--------------------------------
+  ! Calculate various error norms 
+  !--------------------------------
   subroutine calculate_errors(xexact,yexact,xpts,ypts,residual,errL1,errL2,errLinf)
-   implicit none
-   real, dimension(:), intent(in) :: xexact,yexact,xpts,ypts
-   real, dimension(size(xpts)), intent(out) :: residual
+   real, intent(in)  :: xexact(:),yexact(:),xpts(:),ypts(:)
+   real, intent(out) :: residual(size(xpts))
    real, intent(out) :: errL1,errL2,errLinf
    integer :: i,j,npart,iused,nerr
-   real :: xi,dy,dx,yexacti,err1,ymax
+   real    :: xi,dy,dx,yexacti,err1,ymax
 
    errL1 = 0.
    errL2 = 0.
@@ -1190,12 +1281,14 @@ contains
    return
   end subroutine calculate_errors
 
+  !------------------------------------
+  ! Plot residual errors as inset plot 
+  !------------------------------------
   subroutine plot_residuals(xpts,residuals,imarker,iaxisy)
    use plotlib, only:plot_qvp,plot_qwin,plot_svp,plot_qci,plot_qfs, &
                      plot_qcs,plot_sci,plot_sfs,plot_svp,plot_box, &
                      plot_pt,plot_swin,plot_rect
-   implicit none
-   real, dimension(:), intent(in) :: xpts,residuals
+   real,    intent(in) :: xpts(:),residuals(:)
    integer, intent(in) :: imarker,iaxisy
    real :: vptxminold,vptxmaxold,vptyminold,vptymaxold
    real :: vptxmin,vptxmax,vptymin,vptymax
