@@ -15,7 +15,7 @@
 !  a) You must cause the modified files to carry prominent notices
 !     stating that you changed the files and the date of any change.
 !
-!  Copyright (C) 2005-2013 Daniel Price. All rights reserved.
+!  Copyright (C) 2005-2014 Daniel Price. All rights reserved.
 !  Contact: daniel.price@monash.edu
 !
 !-----------------------------------------------------------------
@@ -40,7 +40,7 @@ subroutine menu
                              buffer_data,ncolumns
   use settings_limits,  only:submenu_limits,iadapt
   use settings_part,    only:submenu_particleplots
-  use settings_page,    only:submenu_page,submenu_legend,interactive
+  use settings_page,    only:submenu_page,submenu_legend,interactive,nacross,ndown
   use settings_render,  only:submenu_render,iplotcont_nomulti,icolours,double_rendering
   use settings_vecplot, only:submenu_vecplot,iplotpartvec
   use settings_xsecrot, only:submenu_xsecrotate
@@ -56,8 +56,9 @@ subroutine menu
   integer            :: ipicky,ipickx,irender,ivecplot,icontourplot
   integer            :: iamvecprev, ivecplottemp,ichoose
   character(len=2)   :: ioption
-  character(len=100) :: vecprompt
+  character(len=100) :: vecprompt,string
   character(len=20)  :: rprompt
+  character(len=*), parameter :: sep="(55('-'))"
   logical            :: iAllowRendering
 
   irender = 0
@@ -118,61 +119,66 @@ subroutine menu
 !
 !--data columns
 !
-     print "(/a)",' You may choose from a delectable sample of plots '
-     print 12
+     call print_header()
+     print sep
      ihalf = numplot/2                ! print in two columns
      iadjust = mod(numplot,2)
-     print 11, (i,transform_label(label(i),itrans(i)), &
+     print "(1x,i2,')',1x,a20,1x,i2,')',1x,a20)", &
+          (i,transform_label(label(i),itrans(i)), &
           ihalf + i + iadjust, transform_label(label(ihalf + i + iadjust), &
           itrans(ihalf+i+iadjust)),i=1,ihalf)
      if (iadjust.ne.0) then
-        print 13, ihalf + iadjust,transform_label(label(ihalf + iadjust), &
-             itrans(ihalf+iadjust))
+        print "(1x,i2,')',1x,a20)", &
+              ihalf + iadjust,transform_label(label(ihalf + iadjust), &
+              itrans(ihalf+iadjust))
      endif
 !
 !--multiplot
 !
-     print 12
-     print 18,numplot+1,'multiplot ',nyplotmulti,'m','set multiplot '
+     print sep
+     print "(1x,i2,')',1x,a,'[ ',i2,' ]',5x,a2,') ',a)", &
+           numplot+1,'multiplot ',nyplotmulti,'m','set multiplot '
   else
 !
 !--if no data
 !
      print "(/a)",' No data: You may choose from the options below '
   endif
-
-11 format(1x,i2,')',1x,a20,1x,i2,')',1x,a20)
-12 format(55('-'))
-13 format(1x,i2,')',1x,a20)
-18 format(1x,i2,')',1x,a,'[ ',i2,' ]',5x,a2,') ',a)
-
 !
 !--options
 !
-  print 12
+  print sep
   if (ndim.le.1) then
      print "(a)",' d(ata) p(age) o(pts) l(imits) le(g)end s,S(ave) q(uit)'
   else
      print "(a)",' d(ata) p(age) o(pts) l(imits) le(g)end h(elp)'
      print "(a)",' r(ender) v(ector) x(sec/rotate) s,S(ave) q(uit)'
   endif
-  print 12
+  print sep
 
 !
 !--prompt user for selection
 !
   write(*,"(a)",ADVANCE='NO') 'Please enter your selection now (y axis or option):'
-  read(*,*,iostat=ierr) ioption
+  read(*,"(a)",iostat=ierr) string
   if (ierr < 0) stop 'reached end of input' ! end of input (e.g. in script)
   if (ierr > 0) stop !'error reading input'
+  ioption = string(1:2)
 
 !------------------------------------------------------------
 !  if input is an integer and within range, plot data
 !------------------------------------------------------------
   read(ioption,*,iostat=ierr) ipicky
   if (ierr /= 0) ipicky = -1
+  
+  !--try to read more integers from the string
+  !  if present, use these to set up an "instant multiplot"
+  if (ipicky > 0 .and. ipicky < numplot+1 .and. len_trim(string) > 2) then
+     call set_instant_multiplot(string,ipicky,ipickx,numplot,nyplotmulti,&
+                                multiplotx,multiploty,nacross,ndown)
+  endif
 
-  if (ipicky.gt.0 .and. ipicky.le.numplot+1) then
+  if (ipicky > 0 .and. ipicky <= numplot+1) then
 
      if (.not.ivegotdata) then
         !
@@ -188,8 +194,8 @@ subroutine menu
         !
         !--if needed prompt for x axis selection
         !
-        if (ipicky.le.(numplot-nextra)) then
-           if (ipickx.eq.0) ipickx = 1 ! do not allow zero as default
+        if (ipicky <= (numplot-nextra)) then
+           if (ipickx==0) ipickx = 1 ! do not allow zero as default
            call prompt(' (x axis) ',ipickx)
            !--go back to y prompt if out of range
            if (ipickx.gt.numplot .or. ipickx.le.0) cycle menuloop
@@ -206,28 +212,30 @@ subroutine menu
            !
            if (is_coord(ipicky,ndim) .and. is_coord(ipickx,ndim) .and. iAllowRendering) then
               call prompt('(render) (0=none)',irender,0,(numplot-nextra))
-              if (irender.gt.0 .and. iplotcont_nomulti .and. icolours.ne.0) then
+              if (irender > 0 .and. iplotcont_nomulti .and. icolours /= 0) then
                  if (double_rendering) then
                     rprompt = '2nd render'
                  else
                     rprompt = 'contours'
                  endif
                  call prompt('('//trim(rprompt)//') (0=none)',icontourplot,0,(numplot-nextra))
-                 if (icontourplot.eq.irender) then
+                 if (icontourplot==irender) then
                     if (iadapt) then
                        print "(a)",' limits for '//trim(rprompt)//' are adaptive'
                     else
                        if (.not.lim2set(icontourplot)) lim2(icontourplot,:) = lim(icontourplot,:)
                        call prompt(' enter min for '//trim(rprompt)//':',lim2(icontourplot,1))
                        call prompt(' enter max for '//trim(rprompt)//':',lim2(icontourplot,2))
-                       if (all(lim2(icontourplot,:).eq.lim(icontourplot,:))) call reset_lim2(icontourplot)
+                       if (all(abs(lim2(icontourplot,:)-lim(icontourplot,:)) < tiny(lim))) then
+                          call reset_lim2(icontourplot)
+                       endif
                     endif
                  endif
               endif
               if (any(iamvec(1:numplot).ne.0)) then
                  ivecplottemp = -1
                  ierr = 1
-                 do while(ierr.ne.0 .and. ivecplottemp.ne.0)
+                 do while(ierr /= 0 .and. ivecplottemp /= 0)
                     ivecplottemp = ivecplot
                     ierr = 0
                     call prompt('(vector plot) ('//trim(vecprompt)//')',ivecplottemp,0,maxval(iamvec))
@@ -247,29 +255,29 @@ subroutine menu
               irender = 0
               ivecplot = 0
            endif
-        elseif (ipicky.gt.0 .and. ipicky.eq.itoomre .or. ipicky.eq.isurfdens) then
-            if (ipicky.eq.isurfdens) print "(a)",' setting x axis to r for surface density plot'
-            if (ipicky.eq.itoomre) print "(a)",' setting x axis to r for Toomre Q plot'
+        elseif (ipicky > 0 .and. ipicky==itoomre .or. ipicky==isurfdens) then
+            if (ipicky==isurfdens) print "(a)",' setting x axis to r for surface density plot'
+            if (ipicky==itoomre) print "(a)",' setting x axis to r for Toomre Q plot'
             ipickx = 1
             irender = 0
             ivecplot = 0
-        elseif (ipicky.gt.0 .and. ipicky.eq.ipdf) then
+        elseif (ipicky > 0 .and. ipicky==ipdf) then
             call prompt(' enter x axis for PDF calculation ',ipickx,1,ndataplots)
             irender = 0
             ivecplot = 0
-        elseif (ipicky.gt.0 .and. ipicky.eq.icolpixmap) then
+        elseif (ipicky > 0 .and. ipicky==icolpixmap) then
             call prompt(' enter corresponding SPH column for particle data ',irender,0,ndataplots)
             ipickx = 0
             ivecplot = 0
-        elseif (ipicky.eq.numplot+1) then
+        elseif (ipicky==numplot+1) then
         !
         !--for multiplots, check that options are valid. If not, re-prompt for multiplot
         !  settings
         !
-            if (any(multiploty(1:nyplotmulti).le.0) .or. &
-                any(multiploty(1:nyplotmulti).gt.numplot) .or. &
-                any(multiplotx(1:nyplotmulti).le.0) .or. &
-                any(multiplotx(1:nyplotmulti).gt.numplot)) then
+            if (any(multiploty(1:nyplotmulti) <= 0) .or. &
+                any(multiploty(1:nyplotmulti) > numplot) .or. &
+                any(multiplotx(1:nyplotmulti) <= 0) .or. &
+                any(multiplotx(1:nyplotmulti) > numplot)) then
                print "(/,a,/)",'ERROR: multiplot settings out of range, please re-enter these'
                call options_multiplot
             endif
@@ -282,7 +290,7 @@ subroutine menu
 !------------------------------------------------------------------------
 !  if input is an integer > numplot+1, quit
 !------------------------------------------------------------------------
-  elseif (ipicky.gt.numplot+1) then
+  elseif (ipicky > numplot+1) then
      return
   else
 !------------------------------------------------------------------------
@@ -473,7 +481,9 @@ subroutine menu
                   if (.not.lim2set(icontourmulti(i))) lim2(icontourmulti(i),:) = lim(icontourmulti(i),:)
                   call prompt(' enter min for '//trim(rprompt)//':',lim2(icontourmulti(i),1))
                   call prompt(' enter max for '//trim(rprompt)//':',lim2(icontourmulti(i),2))
-                  if (all(lim2(icontourmulti(i),:).eq.lim(icontourmulti(i),:))) call reset_lim2(icontourmulti(i))
+                  if (all(abs(lim2(icontourmulti(i),:)-lim(icontourmulti(i),:)) < tiny(lim))) then
+                     call reset_lim2(icontourmulti(i))
+                  endif
                endif
             endif
          else
@@ -673,14 +683,14 @@ subroutine set_extracols(ncolumns,ncalc,nextra,numplot,ndataplots)
        label(ipdf) = 'PDF'
     endif
 
-    if (ndim.le.1) then !! .or. ndim.eq.3) then ! if 1D or no coord data (then prompts for which x)
+    if (ndim.le.1 .and. lenvironment('SPLASH_TURB')) then !! .or. ndim.eq.3) then ! if 1D or no coord data (then prompts for which x)
        nextra = nextra + 1      ! one extra plot = power spectrum
        ipowerspec = ncolumns + ncalc + nextra
        label(ipowerspec) = '1D power spectrum'
     else
        ipowerspec = 0
     endif
-    if (iexact.eq.4) then       ! toy star plot a-c plane
+    if (iexact.eq.6) then       ! toy star plot a-c plane
        nextra = nextra + 1
        iacplane = ncolumns + ncalc + nextra
        label(iacplane) = 'a-c plane'
@@ -722,4 +732,62 @@ subroutine set_extracols(ncolumns,ncalc,nextra,numplot,ndataplots)
  return
 end subroutine set_extracols
 
+!----------------------------------------
+! instant multiplot setup from main menu
+!----------------------------------------
+subroutine set_instant_multiplot(string,ipicky,ipickx,numplot,nmulti,multiplotx,multiploty,nx,ny)
+ use params, only:maxplot
+ use prompting, only:prompt
+ character(len=*), intent(in) :: string
+ integer, intent(in) :: numplot
+ integer, intent(inout) :: ipicky,ipickx
+ integer, intent(inout) :: nmulti,nx,ny
+ integer, intent(inout) :: multiplotx(:),multiploty(:)
+ integer :: ipickarr(maxplot),ierr,i
+ 
+ ipickarr = 0
+ read(string,*,iostat=ierr) ipickarr
+ i = 1
+ do while (i < size(ipickarr) .and. ipickarr(i) /= 0 .and. ipickarr(i) <= numplot)
+    i = i + 1
+ enddo
+ if (i > 2) then
+    nmulti = i-1
+    !--make sure nmulti matches the number of panels on the page
+    if (nmulti /= nx*ny) then
+       nx = 1
+       ny = nmulti
+    endif
+    multiploty(1:nmulti) = ipickarr(1:nmulti)
+    ipicky = numplot + 1
+    if (ipickx==0) ipickx = 1 ! do not allow zero as default
+    call prompt(' (x axis) ',ipickx)
+    multiplotx(1:nmulti) = ipickx
+ endif
+
+end subroutine set_instant_multiplot
+
+!--------------------
+! print menu header
+!--------------------
+subroutine print_header
+ integer :: v(8),i
+ integer, parameter :: m(48) = (/32,68,111,110,39,116,32,102,111,114,103,101,116,32,116,111,&
+                      32,115,101,110,100,32,68,97,110,105,101,108,32,97,32,98,&
+                      105,114,116,104,100,97,121,32,109,101,115,115,97,103,101,33/)
+ integer, parameter :: c(49) = (/32,120,111,120,111,120,111,120,111,32,77,101,114,114,121,32,&
+                      67,104,114,105,115,116,109,97,115,32,102,114,111,109,32,115,&
+                      112,108,97,115,104,33,32,120,111,120,111,120,111,120,111,120,111/)
+
+ call date_and_time(values=v)
+ if (v(2)==m(1)/4 .and. v(3)==v(2)-2) then
+    print "(/,48(a))",(achar(m(i)),i=1,48)
+ elseif (v(2)==(m(1)-20) .and. v(3)>20) then
+    print "(/,49(a))",(achar(c(i)),i=1,49)
+ else
+    print "(/a)",' You may choose from a delectable sample of plots'
+ endif
+
+end subroutine print_header
+
 end module mainmenu
